@@ -3,6 +3,25 @@
 #
 # Generated  by generateDS.py.
 #
+# Command line options:
+#   ('--no-dates', '')
+#   ('--no-versions', '')
+#   ('--silence', '')
+#   ('--member-specs', 'list')
+#   ('-f', '')
+#   ('-o', 'tests/anywildcard2_sup.py')
+#   ('-s', 'tests/anywildcard2_sub.py')
+#   ('--super', 'anywildcard2_sup')
+#
+# Command line arguments:
+#   tests/anywildcard.xsd
+#
+# Command line:
+#   generateDS.py --no-dates --no-versions --silence --member-specs="list" -f -o "tests/anywildcard2_sup.py" -s "tests/anywildcard2_sub.py" --super="anywildcard2_sup" tests/anywildcard.xsd
+#
+# Current working directory (os.getcwd()):
+#   generateds
+#
 
 import sys
 
@@ -191,9 +210,9 @@ def parseString(inString, silence=False):
 def parseLiteral(inFilename, silence=False):
     doc = parsexml_(inFilename)
     rootNode = doc.getroot()
-    roots = get_root_tag(rootNode)
-    rootClass = roots[1]
+    rootTag, rootClass = get_root_tag(rootNode)
     if rootClass is None:
+        rootTag = 'PlantType_single'
         rootClass = supermod.PlantType_single
     rootObj = rootClass.factory()
     rootObj.build(rootNode)
@@ -202,8 +221,8 @@ def parseLiteral(inFilename, silence=False):
 ##     if not silence:
 ##         sys.stdout.write('#from anywildcard2_sup import *\n\n')
 ##         sys.stdout.write('import anywildcard2_sup as model_\n\n')
-##         sys.stdout.write('rootObj = model_.PlantType_single(\n')
-##         rootObj.exportLiteral(sys.stdout, 0, name_="PlantType_single")
+##         sys.stdout.write('rootObj = model_.rootClass(\n')
+##         rootObj.exportLiteral(sys.stdout, 0, name_=rootTag)
 ##         sys.stdout.write(')\n')
     return rootObj
 
